aboutsummaryrefslogtreecommitdiffstats
path: root/src/osmo-bts-oc2g/oml.c
diff options
context:
space:
mode:
authorPau Espin Pedrol <pespin@sysmocom.de>2021-06-29 12:16:32 +0200
committerpespin <pespin@sysmocom.de>2021-07-05 08:03:08 +0000
commita4b90739898a9cf652c8365518b87b01806d5e9c (patch)
treef3f75dcef92e53c04426b110edc51a25038fc799 /src/osmo-bts-oc2g/oml.c
parent30aea88c2cc09b8da4252ba7882c01eff0282790 (diff)
Rename osmo dyn ts enums to contain SDCCH8
They will gain support to be activated as SDCCH/8 soon too. Related: SYS#5309 Depends: libosmocore.git I56dcfe4d17899630b17f80145c3ced72f1e91e68 Change-Id: Ia617d20fc52f09dbab8f4516c06fa1efac08e898
Diffstat (limited to 'src/osmo-bts-oc2g/oml.c')
-rw-r--r--src/osmo-bts-oc2g/oml.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/osmo-bts-oc2g/oml.c b/src/osmo-bts-oc2g/oml.c
index 5646cfba..9791ab8b 100644
--- a/src/osmo-bts-oc2g/oml.c
+++ b/src/osmo-bts-oc2g/oml.c
@@ -93,7 +93,7 @@ static const enum GsmL1_LogChComb_t pchan_to_logChComb[_GSM_PCHAN_MAX] = {
[GSM_PCHAN_PDCH] = GsmL1_LogChComb_XIII,
[GSM_PCHAN_UNKNOWN] = GsmL1_LogChComb_0,
/*
* GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
* part of this, only "real" pchan values will be looked up here.
* See the callers of ts_connect_as().
*/
@@ -540,7 +540,7 @@ static int ts_connect_as(struct gsm_bts_trx_ts *ts,
GsmL1_MphConnectReq_t *cr;
if (pchan == GSM_PCHAN_TCH_F_PDCH
- || pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH) {
+ || pchan == GSM_PCHAN_OSMO_DYN) {
LOGP(DL1C, LOGL_ERROR,
"%s Requested TS connect as %s,"
" expected a specific pchan instead\n",
@@ -560,7 +560,7 @@ static int ts_opstart(struct gsm_bts_trx_ts *ts)
{
enum gsm_phys_chan_config pchan = ts->pchan;
switch (pchan) {
- case GSM_PCHAN_TCH_F_TCH_H_PDCH:
+ case GSM_PCHAN_OSMO_DYN:
ts->dyn.pchan_is = ts->dyn.pchan_want = GSM_PCHAN_NONE;
/* First connect as NONE, until first RSL CHAN ACT. */
pchan = GSM_PCHAN_NONE;
@@ -595,7 +595,7 @@ GsmL1_SubCh_t lchan_to_GsmL1_SubCh_t(const struct gsm_lchan *lchan)
{
enum gsm_phys_chan_config pchan = lchan->ts->pchan;
- if (pchan == GSM_PCHAN_TCH_F_TCH_H_PDCH)
+ if (pchan == GSM_PCHAN_OSMO_DYN)
pchan = lchan->ts->dyn.pchan_want;
switch (pchan) {
@@ -614,7 +614,7 @@ GsmL1_SubCh_t lchan_to_GsmL1_SubCh_t(const struct gsm_lchan *lchan)
case GSM_PCHAN_PDCH:
case GSM_PCHAN_UNKNOWN:
default:
/* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
return GsmL1_SubCh_NA;
}
@@ -93,7 +93,7 @@ static const enum GsmL1_LogChComb_t pchan_to_logChComb[_GSM_PCHAN_MAX] = {
[GSM_PCHAN_UNKNOWN] = GsmL1_LogChComb_0,
/*
- * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_TCH_F_TCH_H_PDCH should not be
+ * GSM_PCHAN_TCH_F_PDCH and GSM_PCHAN_OSMO_DYN should not be
* part of this, only "real" pchan values will be looked up here.
* See the callers of ts_connect_as().
@@ -614,7 +614,7 @@ GsmL1_SubCh_t lchan_to_GsmL1_SubCh_t(const struct gsm_lchan *lchan)
case GSM_PCHAN_UNKNOWN:
default:
- /* case GSM_PCHAN_TCH_F_TCH_H_PDCH: is caught above */
+ /* case GSM_PCHAN_OSMO_DYN: is caught above */
return GsmL1_SubCh_NA;
}